# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class SearchSubscriptionContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "can_share_schedule": "bool",
        "default_workflow_credential_id": "str",
        "user_count_greater_than_equals": "int",
        "user_count_less_than_equals": "int",
        "workflow_count_greater_than_equals": "int",
        "workflow_count_less_than_equals": "int",
    }

    attribute_map = {
        "name": "name",
        "can_share_schedule": "canShareSchedule",
        "default_workflow_credential_id": "defaultWorkflowCredentialId",
        "user_count_greater_than_equals": "userCountGreaterThanEquals",
        "user_count_less_than_equals": "userCountLessThanEquals",
        "workflow_count_greater_than_equals": "workflowCountGreaterThanEquals",
        "workflow_count_less_than_equals": "workflowCountLessThanEquals",
    }

    def __init__(
        self,
        name=None,
        can_share_schedule=None,
        default_workflow_credential_id=None,
        user_count_greater_than_equals=None,
        user_count_less_than_equals=None,
        workflow_count_greater_than_equals=None,
        workflow_count_less_than_equals=None,
        _configuration=None,
    ):  # noqa: E501
        """SearchSubscriptionContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._can_share_schedule = None
        self._default_workflow_credential_id = None
        self._user_count_greater_than_equals = None
        self._user_count_less_than_equals = None
        self._workflow_count_greater_than_equals = None
        self._workflow_count_less_than_equals = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if can_share_schedule is not None:
            self.can_share_schedule = can_share_schedule
        if default_workflow_credential_id is not None:
            self.default_workflow_credential_id = default_workflow_credential_id
        if user_count_greater_than_equals is not None:
            self.user_count_greater_than_equals = user_count_greater_than_equals
        if user_count_less_than_equals is not None:
            self.user_count_less_than_equals = user_count_less_than_equals
        if workflow_count_greater_than_equals is not None:
            self.workflow_count_greater_than_equals = workflow_count_greater_than_equals
        if workflow_count_less_than_equals is not None:
            self.workflow_count_less_than_equals = workflow_count_less_than_equals

    @property
    def name(self):
        """Gets the name of this SearchSubscriptionContract.  # noqa: E501


        :return:
            The name of this SearchSubscriptionContract.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SearchSubscriptionContract.


        :param name:
            The name of this SearchSubscriptionContract.
        :type: str
        """

        self._name = name

    @property
    def can_share_schedule(self):
        """Gets the can_share_schedule of this SearchSubscriptionContract.  # noqa: E501


        :return: The can_share_schedule of this SearchSubscriptionContract.  # noqa: E501
        :rtype: bool
        """
        return self._can_share_schedule

    @can_share_schedule.setter
    def can_share_schedule(self, can_share_schedule):
        """Sets the can_share_schedule of this SearchSubscriptionContract.


        :param can_share_schedule:
            The can_share_schedule of this SearchSubscriptionContract.
        :type: bool
        """

        self._can_share_schedule = can_share_schedule

    @property
    def default_workflow_credential_id(self):
        """Gets the default_workflow_credential_id of this SearchSubscriptionContract.  # noqa: E501


        :return: The default_workflow_credential_id of this SearchSubscriptionContract.  # noqa: E501
        :rtype: str
        """
        return self._default_workflow_credential_id

    @default_workflow_credential_id.setter
    def default_workflow_credential_id(self, default_workflow_credential_id):
        """Sets the default_workflow_credential_id of this SearchSubscriptionContract.


        :param default_workflow_credential_id:
            The default_workflow_credential_id of this SearchSubscriptionContract.
        :type: str
        """

        self._default_workflow_credential_id = default_workflow_credential_id

    @property
    def user_count_greater_than_equals(self):
        """Gets the user_count_greater_than_equals of this SearchSubscriptionContract.  # noqa: E501


        :return: The user_count_greater_than_equals of this SearchSubscriptionContract.  # noqa: E501
        :rtype: int
        """
        return self._user_count_greater_than_equals

    @user_count_greater_than_equals.setter
    def user_count_greater_than_equals(self, user_count_greater_than_equals):
        """Sets the user_count_greater_than_equals of this SearchSubscriptionContract.


        :param user_count_greater_than_equals: The user_count_greater_than_equals of 
            this SearchSubscriptionContract.  # noqa: E501  
        :type: int
        """

        self._user_count_greater_than_equals = user_count_greater_than_equals

    @property
    def user_count_less_than_equals(self):
        """Gets the user_count_less_than_equals of this SearchSubscriptionContract.  # noqa: E501


        :return: The user_count_less_than_equals of this SearchSubscriptionContract.  # noqa: E501
        :rtype: int
        """
        return self._user_count_less_than_equals

    @user_count_less_than_equals.setter
    def user_count_less_than_equals(self, user_count_less_than_equals):
        """Sets the user_count_less_than_equals of this SearchSubscriptionContract.


        :param user_count_less_than_equals:
            The user_count_less_than_equals of this SearchSubscriptionContract.
        :type: int
        """

        self._user_count_less_than_equals = user_count_less_than_equals

    @property
    def workflow_count_greater_than_equals(self):
        """Gets the workflow_count_greater_than_equals of this SearchSubscriptionContract.  # noqa: E501


        :return: The workflow_count_greater_than_equals of this SearchSubscriptionContract.  # noqa: E501
        :rtype: int
        """
        return self._workflow_count_greater_than_equals

    @workflow_count_greater_than_equals.setter
    def workflow_count_greater_than_equals(self, workflow_count_greater_than_equals):
        """Sets the workflow_count_greater_than_equals of this SearchSubscriptionContract.


        :param workflow_count_greater_than_equals:
            The workflow_count_greater_than_equals of this SearchSubscriptionContract.
        :type: int
        """

        self._workflow_count_greater_than_equals = workflow_count_greater_than_equals

    @property
    def workflow_count_less_than_equals(self):
        """Gets the workflow_count_less_than_equals of this SearchSubscriptionContract.  # noqa: E501


        :return: The workflow_count_less_than_equals of this SearchSubscriptionContract.  # noqa: E501
        :rtype: int
        """
        return self._workflow_count_less_than_equals

    @workflow_count_less_than_equals.setter
    def workflow_count_less_than_equals(self, workflow_count_less_than_equals):
        """Sets the workflow_count_less_than_equals of this SearchSubscriptionContract.


        :param workflow_count_less_than_equals:
            The workflow_count_less_than_equals of this SearchSubscriptionContract.
        :type: int
        """

        self._workflow_count_less_than_equals = workflow_count_less_than_equals

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(SearchSubscriptionContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchSubscriptionContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchSubscriptionContract):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class WorkflowView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "source_app_id": "str",
        "date_created": "datetime",
        "run_count": "int",
        "versions": "list[WorkflowVersionView]",
        "name": "str",
        "owner_id": "str",
        "worker_tag": "str",
        "district_tags": "list[str]",
        "comments": "str",
        "is_public": "bool",
        "is_ready_for_migration": "bool",
        "published_version_id": "str",
        "others_may_download": "bool",
        "others_can_view_history": "bool",
        "others_can_execute": "bool",
        "execution_mode": "str",
        "has_private_data_exemption": "bool",
    }

    attribute_map = {
        "id": "id",
        "source_app_id": "sourceAppId",
        "date_created": "dateCreated",
        "run_count": "runCount",
        "versions": "versions",
        "name": "name",
        "owner_id": "ownerId",
        "worker_tag": "workerTag",
        "district_tags": "districtTags",
        "comments": "comments",
        "is_public": "isPublic",
        "is_ready_for_migration": "isReadyForMigration",
        "published_version_id": "publishedVersionId",
        "others_may_download": "othersMayDownload",
        "others_can_view_history": "othersCanViewHistory",
        "others_can_execute": "othersCanExecute",
        "execution_mode": "executionMode",
        "has_private_data_exemption": "hasPrivateDataExemption",
    }

    def __init__(
        self,
        id=None,
        source_app_id=None,
        date_created=None,
        run_count=None,
        versions=None,
        name=None,
        owner_id=None,
        worker_tag=None,
        district_tags=None,
        comments=None,
        is_public=None,
        is_ready_for_migration=None,
        published_version_id=None,
        others_may_download=None,
        others_can_view_history=None,
        others_can_execute=None,
        execution_mode=None,
        has_private_data_exemption=None,
        _configuration=None,
    ):  # noqa: E501
        """WorkflowView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._source_app_id = None
        self._date_created = None
        self._run_count = None
        self._versions = None
        self._name = None
        self._owner_id = None
        self._worker_tag = None
        self._district_tags = None
        self._comments = None
        self._is_public = None
        self._is_ready_for_migration = None
        self._published_version_id = None
        self._others_may_download = None
        self._others_can_view_history = None
        self._others_can_execute = None
        self._execution_mode = None
        self._has_private_data_exemption = None
        self.discriminator = None

        self.id = id
        self.source_app_id = source_app_id
        self.date_created = date_created
        self.run_count = run_count
        self.versions = versions
        self.name = name
        self.owner_id = owner_id
        self.worker_tag = worker_tag
        self.district_tags = district_tags
        self.comments = comments
        self.is_public = is_public
        self.is_ready_for_migration = is_ready_for_migration
        self.published_version_id = published_version_id
        self.others_may_download = others_may_download
        self.others_can_view_history = others_can_view_history
        self.others_can_execute = others_can_execute
        if execution_mode is not None:
            self.execution_mode = execution_mode
        if has_private_data_exemption is not None:
            self.has_private_data_exemption = has_private_data_exemption

    @property
    def id(self):
        """Gets the id of this WorkflowView.  # noqa: E501


        :return: The id of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowView.


        :param id: The id of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def source_app_id(self):
        """Gets the source_app_id of this WorkflowView.  # noqa: E501


        :return: The source_app_id of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._source_app_id

    @source_app_id.setter
    def source_app_id(self, source_app_id):
        """Sets the source_app_id of this WorkflowView.


        :param source_app_id: The source_app_id of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and source_app_id is None:
            raise ValueError("Invalid value for `source_app_id`, must not be `None`")  # noqa: E501

        self._source_app_id = source_app_id

    @property
    def date_created(self):
        """Gets the date_created of this WorkflowView.  # noqa: E501


        :return: The date_created of this WorkflowView.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this WorkflowView.


        :param date_created: The date_created of this WorkflowView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def run_count(self):
        """Gets the run_count of this WorkflowView.  # noqa: E501


        :return: The run_count of this WorkflowView.  # noqa: E501
        :rtype: int
        """
        return self._run_count

    @run_count.setter
    def run_count(self, run_count):
        """Sets the run_count of this WorkflowView.


        :param run_count: The run_count of this WorkflowView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and run_count is None:
            raise ValueError("Invalid value for `run_count`, must not be `None`")  # noqa: E501

        self._run_count = run_count

    @property
    def versions(self):
        """Gets the versions of this WorkflowView.  # noqa: E501


        :return: The versions of this WorkflowView.  # noqa: E501
        :rtype: list[WorkflowVersionView]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this WorkflowView.


        :param versions: The versions of this WorkflowView.  # noqa: E501
        :type: list[WorkflowVersionView]
        """
        if self._configuration.client_side_validation and versions is None:
            raise ValueError("Invalid value for `versions`, must not be `None`")  # noqa: E501

        self._versions = versions

    @property
    def name(self):
        """Gets the name of this WorkflowView.  # noqa: E501


        :return: The name of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowView.


        :param name: The name of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def owner_id(self):
        """Gets the owner_id of this WorkflowView.  # noqa: E501


        :return: The owner_id of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this WorkflowView.


        :param owner_id: The owner_id of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and owner_id is None:
            raise ValueError("Invalid value for `owner_id`, must not be `None`")  # noqa: E501

        self._owner_id = owner_id

    @property
    def worker_tag(self):
        """Gets the worker_tag of this WorkflowView.  # noqa: E501


        :return: The worker_tag of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._worker_tag

    @worker_tag.setter
    def worker_tag(self, worker_tag):
        """Sets the worker_tag of this WorkflowView.


        :param worker_tag: The worker_tag of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and worker_tag is None:
            raise ValueError("Invalid value for `worker_tag`, must not be `None`")  # noqa: E501

        self._worker_tag = worker_tag

    @property
    def district_tags(self):
        """Gets the district_tags of this WorkflowView.  # noqa: E501


        :return: The district_tags of this WorkflowView.  # noqa: E501
        :rtype: list[str]
        """
        return self._district_tags

    @district_tags.setter
    def district_tags(self, district_tags):
        """Sets the district_tags of this WorkflowView.


        :param district_tags: The district_tags of this WorkflowView.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and district_tags is None:
            raise ValueError("Invalid value for `district_tags`, must not be `None`")  # noqa: E501

        self._district_tags = district_tags

    @property
    def comments(self):
        """Gets the comments of this WorkflowView.  # noqa: E501


        :return: The comments of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this WorkflowView.


        :param comments: The comments of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and comments is None:
            raise ValueError("Invalid value for `comments`, must not be `None`")  # noqa: E501

        self._comments = comments

    @property
    def is_public(self):
        """Gets the is_public of this WorkflowView.  # noqa: E501


        :return: The is_public of this WorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this WorkflowView.


        :param is_public: The is_public of this WorkflowView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_public is None:
            raise ValueError("Invalid value for `is_public`, must not be `None`")  # noqa: E501

        self._is_public = is_public

    @property
    def is_ready_for_migration(self):
        """Gets the is_ready_for_migration of this WorkflowView.  # noqa: E501


        :return: The is_ready_for_migration of this WorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._is_ready_for_migration

    @is_ready_for_migration.setter
    def is_ready_for_migration(self, is_ready_for_migration):
        """Sets the is_ready_for_migration of this WorkflowView.


        :param is_ready_for_migration: The is_ready_for_migration of this WorkflowView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_ready_for_migration is None:
            raise ValueError("Invalid value for `is_ready_for_migration`, must not be `None`")  # noqa: E501

        self._is_ready_for_migration = is_ready_for_migration

    @property
    def published_version_id(self):
        """Gets the published_version_id of this WorkflowView.  # noqa: E501


        :return: The published_version_id of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._published_version_id

    @published_version_id.setter
    def published_version_id(self, published_version_id):
        """Sets the published_version_id of this WorkflowView.


        :param published_version_id: The published_version_id of this WorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and published_version_id is None:
            raise ValueError("Invalid value for `published_version_id`, must not be `None`")  # noqa: E501

        self._published_version_id = published_version_id

    @property
    def others_may_download(self):
        """Gets the others_may_download of this WorkflowView.  # noqa: E501


        :return: The others_may_download of this WorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._others_may_download

    @others_may_download.setter
    def others_may_download(self, others_may_download):
        """Sets the others_may_download of this WorkflowView.


        :param others_may_download: The others_may_download of this WorkflowView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and others_may_download is None:
            raise ValueError("Invalid value for `others_may_download`, must not be `None`")  # noqa: E501

        self._others_may_download = others_may_download

    @property
    def others_can_view_history(self):
        """Gets the others_can_view_history of this WorkflowView.  # noqa: E501


        :return: The others_can_view_history of this WorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._others_can_view_history

    @others_can_view_history.setter
    def others_can_view_history(self, others_can_view_history):
        """Sets the others_can_view_history of this WorkflowView.


        :param others_can_view_history: The others_can_view_history of this WorkflowView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and others_can_view_history is None:
            raise ValueError("Invalid value for `others_can_view_history`, must not be `None`")  # noqa: E501

        self._others_can_view_history = others_can_view_history

    @property
    def others_can_execute(self):
        """Gets the others_can_execute of this WorkflowView.  # noqa: E501


        :return: The others_can_execute of this WorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._others_can_execute

    @others_can_execute.setter
    def others_can_execute(self, others_can_execute):
        """Sets the others_can_execute of this WorkflowView.


        :param others_can_execute: The others_can_execute of this WorkflowView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and others_can_execute is None:
            raise ValueError("Invalid value for `others_can_execute`, must not be `None`")  # noqa: E501

        self._others_can_execute = others_can_execute

    @property
    def execution_mode(self):
        """Gets the execution_mode of this WorkflowView.  # noqa: E501


        :return: The execution_mode of this WorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._execution_mode

    @execution_mode.setter
    def execution_mode(self, execution_mode):
        """Sets the execution_mode of this WorkflowView.


        :param execution_mode: The execution_mode of this WorkflowView.  # noqa: E501
        :type: str
        """
        allowed_values = ["Safe", "SemiSafe", "Standard"]  # noqa: E501
        if self._configuration.client_side_validation and execution_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `execution_mode` ({0}), must be one of {1}".format(execution_mode, allowed_values)  # noqa: E501
            )

        self._execution_mode = execution_mode

    @property
    def has_private_data_exemption(self):
        """Gets the has_private_data_exemption of this WorkflowView.  # noqa: E501


        :return: The has_private_data_exemption of this WorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._has_private_data_exemption

    @has_private_data_exemption.setter
    def has_private_data_exemption(self, has_private_data_exemption):
        """Sets the has_private_data_exemption of this WorkflowView.


        :param has_private_data_exemption: The has_private_data_exemption of this WorkflowView.  # noqa: E501
        :type: bool
        """

        self._has_private_data_exemption = has_private_data_exemption

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(WorkflowView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class ReducedUserView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "first_name": "str",
        "last_name": "str",
        "email": "str",
        "is_active": "bool",
        "role": "str",
        "date_created": "datetime",
    }

    attribute_map = {
        "id": "id",
        "first_name": "firstName",
        "last_name": "lastName",
        "email": "email",
        "is_active": "isActive",
        "role": "role",
        "date_created": "dateCreated",
    }

    def __init__(
        self,
        id=None,
        first_name=None,
        last_name=None,
        email=None,
        is_active=None,
        role=None,
        date_created=None,
        _configuration=None,
    ):  # noqa: E501
        """ReducedUserView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._first_name = None
        self._last_name = None
        self._email = None
        self._is_active = None
        self._role = None
        self._date_created = None
        self.discriminator = None

        self.id = id
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.is_active = is_active
        self.role = role
        self.date_created = date_created

    @property
    def id(self):
        """Gets the id of this ReducedUserView.  # noqa: E501


        :return: The id of this ReducedUserView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReducedUserView.


        :param id: The id of this ReducedUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def first_name(self):
        """Gets the first_name of this ReducedUserView.  # noqa: E501


        :return: The first_name of this ReducedUserView.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this ReducedUserView.


        :param first_name: The first_name of this ReducedUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this ReducedUserView.  # noqa: E501


        :return: The last_name of this ReducedUserView.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this ReducedUserView.


        :param last_name: The last_name of this ReducedUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this ReducedUserView.  # noqa: E501


        :return: The email of this ReducedUserView.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ReducedUserView.


        :param email: The email of this ReducedUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def is_active(self):
        """Gets the is_active of this ReducedUserView.  # noqa: E501


        :return: The is_active of this ReducedUserView.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this ReducedUserView.


        :param is_active: The is_active of this ReducedUserView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_active is None:
            raise ValueError("Invalid value for `is_active`, must not be `None`")  # noqa: E501

        self._is_active = is_active

    @property
    def role(self):
        """Gets the role of this ReducedUserView.  # noqa: E501


        :return: The role of this ReducedUserView.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this ReducedUserView.


        :param role: The role of this ReducedUserView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["NoAccess", "Viewer", "Member", "Artisan", "Curator", "Evaluated"]  # noqa: E501
        if self._configuration.client_side_validation and role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}".format(role, allowed_values)  # noqa: E501
            )

        self._role = role

    @property
    def date_created(self):
        """Gets the date_created of this ReducedUserView.  # noqa: E501


        :return: The date_created of this ReducedUserView.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ReducedUserView.


        :param date_created: The date_created of this ReducedUserView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ReducedUserView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReducedUserView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReducedUserView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class WorkflowVersionView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "version_id": "str",
        "version_number": "int",
        "date_created": "datetime",
        "upload_source": "str",
        "upload_date": "datetime",
        "package_workflow_type": "str",
        "published": "bool",
        "comments": "str",
        "run_disabled": "bool",
        "execution_mode": "str",
        "workflow_credential_type": "str",
        "credential_id": "str",
        "has_private_data_exemption": "bool",
        "others_may_download": "bool",
        "others_can_view_history": "bool",
        "details": "WorkflowDetails",
    }

    attribute_map = {
        "version_id": "versionId",
        "version_number": "versionNumber",
        "date_created": "dateCreated",
        "upload_source": "uploadSource",
        "upload_date": "uploadDate",
        "package_workflow_type": "packageWorkflowType",
        "published": "published",
        "comments": "comments",
        "run_disabled": "runDisabled",
        "execution_mode": "executionMode",
        "workflow_credential_type": "workflowCredentialType",
        "credential_id": "credentialId",
        "has_private_data_exemption": "hasPrivateDataExemption",
        "others_may_download": "othersMayDownload",
        "others_can_view_history": "othersCanViewHistory",
        "details": "details",
    }

    def __init__(
        self,
        version_id=None,
        version_number=None,
        date_created=None,
        upload_source=None,
        upload_date=None,
        package_workflow_type=None,
        published=None,
        comments=None,
        run_disabled=None,
        execution_mode=None,
        workflow_credential_type=None,
        credential_id=None,
        has_private_data_exemption=None,
        others_may_download=None,
        others_can_view_history=None,
        details=None,
        _configuration=None,
    ):  # noqa: E501
        """WorkflowVersionView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._version_id = None
        self._version_number = None
        self._date_created = None
        self._upload_source = None
        self._upload_date = None
        self._package_workflow_type = None
        self._published = None
        self._comments = None
        self._run_disabled = None
        self._execution_mode = None
        self._workflow_credential_type = None
        self._credential_id = None
        self._has_private_data_exemption = None
        self._others_may_download = None
        self._others_can_view_history = None
        self._details = None
        self.discriminator = None

        self.version_id = version_id
        self.version_number = version_number
        self.date_created = date_created
        self.upload_source = upload_source
        self.upload_date = upload_date
        self.package_workflow_type = package_workflow_type
        self.published = published
        self.comments = comments
        self.run_disabled = run_disabled
        self.execution_mode = execution_mode
        self.workflow_credential_type = workflow_credential_type
        self.credential_id = credential_id
        if has_private_data_exemption is not None:
            self.has_private_data_exemption = has_private_data_exemption
        self.others_may_download = others_may_download
        self.others_can_view_history = others_can_view_history
        self.details = details

    @property
    def version_id(self):
        """Gets the version_id of this WorkflowVersionView.  # noqa: E501


        :return: The version_id of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this WorkflowVersionView.


        :param version_id: The version_id of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")  # noqa: E501

        self._version_id = version_id

    @property
    def version_number(self):
        """Gets the version_number of this WorkflowVersionView.  # noqa: E501


        :return: The version_number of this WorkflowVersionView.  # noqa: E501
        :rtype: int
        """
        return self._version_number

    @version_number.setter
    def version_number(self, version_number):
        """Sets the version_number of this WorkflowVersionView.


        :param version_number: The version_number of this WorkflowVersionView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and version_number is None:
            raise ValueError("Invalid value for `version_number`, must not be `None`")  # noqa: E501

        self._version_number = version_number

    @property
    def date_created(self):
        """Gets the date_created of this WorkflowVersionView.  # noqa: E501


        :return: The date_created of this WorkflowVersionView.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this WorkflowVersionView.


        :param date_created: The date_created of this WorkflowVersionView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def upload_source(self):
        """Gets the upload_source of this WorkflowVersionView.  # noqa: E501


        :return: The upload_source of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._upload_source

    @upload_source.setter
    def upload_source(self, upload_source):
        """Sets the upload_source of this WorkflowVersionView.


        :param upload_source: The upload_source of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and upload_source is None:
            raise ValueError("Invalid value for `upload_source`, must not be `None`")  # noqa: E501
        allowed_values = ["Designer", "Direct"]  # noqa: E501
        if self._configuration.client_side_validation and upload_source not in allowed_values:
            raise ValueError(
                "Invalid value for `upload_source` ({0}), must be one of {1}".format(upload_source, allowed_values)  # noqa: E501
            )

        self._upload_source = upload_source

    @property
    def upload_date(self):
        """Gets the upload_date of this WorkflowVersionView.  # noqa: E501


        :return: The upload_date of this WorkflowVersionView.  # noqa: E501
        :rtype: datetime
        """
        return self._upload_date

    @upload_date.setter
    def upload_date(self, upload_date):
        """Sets the upload_date of this WorkflowVersionView.


        :param upload_date: The upload_date of this WorkflowVersionView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and upload_date is None:
            raise ValueError("Invalid value for `upload_date`, must not be `None`")  # noqa: E501

        self._upload_date = upload_date

    @property
    def package_workflow_type(self):
        """Gets the package_workflow_type of this WorkflowVersionView.  # noqa: E501


        :return: The package_workflow_type of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._package_workflow_type

    @package_workflow_type.setter
    def package_workflow_type(self, package_workflow_type):
        """Sets the package_workflow_type of this WorkflowVersionView.


        :param package_workflow_type: The package_workflow_type of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and package_workflow_type is None:
            raise ValueError("Invalid value for `package_workflow_type`, must not be `None`")  # noqa: E501
        allowed_values = ["App", "Module", "Macro"]  # noqa: E501
        if self._configuration.client_side_validation and package_workflow_type not in allowed_values:
            raise ValueError(
                "Invalid value for `package_workflow_type` ({0}), must be one of {1}".format(  # noqa: E501
                    package_workflow_type, allowed_values
                )
            )

        self._package_workflow_type = package_workflow_type

    @property
    def published(self):
        """Gets the published of this WorkflowVersionView.  # noqa: E501


        :return: The published of this WorkflowVersionView.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this WorkflowVersionView.


        :param published: The published of this WorkflowVersionView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and published is None:
            raise ValueError("Invalid value for `published`, must not be `None`")  # noqa: E501

        self._published = published

    @property
    def comments(self):
        """Gets the comments of this WorkflowVersionView.  # noqa: E501


        :return: The comments of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """Sets the comments of this WorkflowVersionView.


        :param comments: The comments of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and comments is None:
            raise ValueError("Invalid value for `comments`, must not be `None`")  # noqa: E501

        self._comments = comments

    @property
    def run_disabled(self):
        """Gets the run_disabled of this WorkflowVersionView.  # noqa: E501


        :return: The run_disabled of this WorkflowVersionView.  # noqa: E501
        :rtype: bool
        """
        return self._run_disabled

    @run_disabled.setter
    def run_disabled(self, run_disabled):
        """Sets the run_disabled of this WorkflowVersionView.


        :param run_disabled: The run_disabled of this WorkflowVersionView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and run_disabled is None:
            raise ValueError("Invalid value for `run_disabled`, must not be `None`")  # noqa: E501

        self._run_disabled = run_disabled

    @property
    def execution_mode(self):
        """Gets the execution_mode of this WorkflowVersionView.  # noqa: E501


        :return: The execution_mode of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._execution_mode

    @execution_mode.setter
    def execution_mode(self, execution_mode):
        """Sets the execution_mode of this WorkflowVersionView.


        :param execution_mode: The execution_mode of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and execution_mode is None:
            raise ValueError("Invalid value for `execution_mode`, must not be `None`")  # noqa: E501
        allowed_values = ["Safe", "SemiSafe", "Standard"]  # noqa: E501
        if self._configuration.client_side_validation and execution_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `execution_mode` ({0}), must be one of {1}".format(execution_mode, allowed_values)  # noqa: E501
            )

        self._execution_mode = execution_mode

    @property
    def workflow_credential_type(self):
        """Gets the workflow_credential_type of this WorkflowVersionView.  # noqa: E501


        :return: The workflow_credential_type of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._workflow_credential_type

    @workflow_credential_type.setter
    def workflow_credential_type(self, workflow_credential_type):
        """Sets the workflow_credential_type of this WorkflowVersionView.


        :param workflow_credential_type: The workflow_credential_type of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and workflow_credential_type is None:
            raise ValueError("Invalid value for `workflow_credential_type`, must not be `None`")  # noqa: E501
        allowed_values = ["Default", "Required", "Specific"]  # noqa: E501
        if self._configuration.client_side_validation and workflow_credential_type not in allowed_values:
            raise ValueError(
                "Invalid value for `workflow_credential_type` ({0}), must be one of {1}".format(  # noqa: E501
                    workflow_credential_type, allowed_values
                )
            )

        self._workflow_credential_type = workflow_credential_type

    @property
    def credential_id(self):
        """Gets the credential_id of this WorkflowVersionView.  # noqa: E501


        :return: The credential_id of this WorkflowVersionView.  # noqa: E501
        :rtype: str
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this WorkflowVersionView.


        :param credential_id: The credential_id of this WorkflowVersionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and credential_id is None:
            raise ValueError("Invalid value for `credential_id`, must not be `None`")  # noqa: E501

        self._credential_id = credential_id

    @property
    def has_private_data_exemption(self):
        """Gets the has_private_data_exemption of this WorkflowVersionView.  # noqa: E501


        :return: The has_private_data_exemption of this WorkflowVersionView.  # noqa: E501
        :rtype: bool
        """
        return self._has_private_data_exemption

    @has_private_data_exemption.setter
    def has_private_data_exemption(self, has_private_data_exemption):
        """Sets the has_private_data_exemption of this WorkflowVersionView.


        :param has_private_data_exemption: The has_private_data_exemption of this WorkflowVersionView.  # noqa: E501
        :type: bool
        """

        self._has_private_data_exemption = has_private_data_exemption

    @property
    def others_may_download(self):
        """Gets the others_may_download of this WorkflowVersionView.  # noqa: E501


        :return: The others_may_download of this WorkflowVersionView.  # noqa: E501
        :rtype: bool
        """
        return self._others_may_download

    @others_may_download.setter
    def others_may_download(self, others_may_download):
        """Sets the others_may_download of this WorkflowVersionView.


        :param others_may_download: The others_may_download of this WorkflowVersionView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and others_may_download is None:
            raise ValueError("Invalid value for `others_may_download`, must not be `None`")  # noqa: E501

        self._others_may_download = others_may_download

    @property
    def others_can_view_history(self):
        """Gets the others_can_view_history of this WorkflowVersionView.  # noqa: E501


        :return: The others_can_view_history of this WorkflowVersionView.  # noqa: E501
        :rtype: bool
        """
        return self._others_can_view_history

    @others_can_view_history.setter
    def others_can_view_history(self, others_can_view_history):
        """Sets the others_can_view_history of this WorkflowVersionView.


        :param others_can_view_history: The others_can_view_history of this WorkflowVersionView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and others_can_view_history is None:
            raise ValueError("Invalid value for `others_can_view_history`, must not be `None`")  # noqa: E501

        self._others_can_view_history = others_can_view_history

    @property
    def details(self):
        """Gets the details of this WorkflowVersionView.  # noqa: E501


        :return: The details of this WorkflowVersionView.  # noqa: E501
        :rtype: WorkflowDetails
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this WorkflowVersionView.


        :param details: The details of this WorkflowVersionView.  # noqa: E501
        :type: WorkflowDetails
        """
        if self._configuration.client_side_validation and details is None:
            raise ValueError("Invalid value for `details`, must not be `None`")  # noqa: E501

        self._details = details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(WorkflowVersionView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowVersionView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowVersionView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class CollectionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def collections_add_schedule_to_collection(self, collection_id, contract, **kwargs):  # noqa: E501
        """Add a schedule to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_schedule_to_collection(collection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddScheduleContract contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_add_schedule_to_collection_with_http_info(collection_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_add_schedule_to_collection_with_http_info(collection_id, contract, **kwargs)  # noqa: E501
            return data

    def collections_add_schedule_to_collection_with_http_info(self, collection_id, contract, **kwargs):  # noqa: E501
        """Add a schedule to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_schedule_to_collection_with_http_info(collection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddScheduleContract contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method collections_add_schedule_to_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_add_schedule_to_collection`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `collections_add_schedule_to_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/schedules",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_add_user_group_to_collection(self, collection_id, add_user_groups_contract, **kwargs):  # noqa: E501
        """Add a user group to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_user_group_to_collection(collection_id, add_user_groups_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddUserGroupContract add_user_groups_contract: User Group and permissions information. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_add_user_group_to_collection_with_http_info(
                collection_id, add_user_groups_contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.collections_add_user_group_to_collection_with_http_info(
                collection_id, add_user_groups_contract, **kwargs
            )  # noqa: E501
            return data

    def collections_add_user_group_to_collection_with_http_info(
        self, collection_id, add_user_groups_contract, **kwargs
    ):  # noqa: E501
        """Add a user group to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_user_group_to_collection_with_http_info(collection_id, add_user_groups_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddUserGroupContract add_user_groups_contract: User Group and permissions information. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "add_user_groups_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method collections_add_user_group_to_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_add_user_group_to_collection`"
            )  # noqa: E501
        # verify the required parameter 'add_user_groups_contract' is set
        if self.api_client.client_side_validation and (
            "add_user_groups_contract" not in params or params["add_user_groups_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `add_user_groups_contract` when calling `collections_add_user_group_to_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "add_user_groups_contract" in params:
            body_params = params["add_user_groups_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/userGroups",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_add_user_to_collection(self, collection_id, add_users_contract, **kwargs):  # noqa: E501
        """Add a user to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_user_to_collection(collection_id, add_users_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddUserContract add_users_contract: User and permissions information. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_add_user_to_collection_with_http_info(collection_id, add_users_contract, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_add_user_to_collection_with_http_info(collection_id, add_users_contract, **kwargs)  # noqa: E501
            return data

    def collections_add_user_to_collection_with_http_info(self, collection_id, add_users_contract, **kwargs):  # noqa: E501
        """Add a user to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_user_to_collection_with_http_info(collection_id, add_users_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddUserContract add_users_contract: User and permissions information. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "add_users_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method collections_add_user_to_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_add_user_to_collection`"
            )  # noqa: E501
        # verify the required parameter 'add_users_contract' is set
        if self.api_client.client_side_validation and (
            "add_users_contract" not in params or params["add_users_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `add_users_contract` when calling `collections_add_user_to_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "add_users_contract" in params:
            body_params = params["add_users_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/users",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_add_workflow_to_collection(self, collection_id, contract, **kwargs):  # noqa: E501
        """Add a workflow to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_workflow_to_collection(collection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddWorkflowContract contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_add_workflow_to_collection_with_http_info(collection_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_add_workflow_to_collection_with_http_info(collection_id, contract, **kwargs)  # noqa: E501
            return data

    def collections_add_workflow_to_collection_with_http_info(self, collection_id, contract, **kwargs):  # noqa: E501
        """Add a workflow to an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_add_workflow_to_collection_with_http_info(collection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param AddWorkflowContract contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method collections_add_workflow_to_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_add_workflow_to_collection`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `collections_add_workflow_to_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/workflows",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_create_collection(self, contract, **kwargs):  # noqa: E501
        """Create a new collection.  # noqa: E501

        Only Curators can use this API endpoint.   The authenticated API user must have the \"Create Collections\" permission to use this endpoint, else 401 Unauthorized will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_create_collection(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCollectionContract contract:  (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_create_collection_with_http_info(contract, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_create_collection_with_http_info(contract, **kwargs)  # noqa: E501
            return data

    def collections_create_collection_with_http_info(self, contract, **kwargs):  # noqa: E501
        """Create a new collection.  # noqa: E501

        Only Curators can use this API endpoint.   The authenticated API user must have the \"Create Collections\" permission to use this endpoint, else 401 Unauthorized will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_create_collection_with_http_info(contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateCollectionContract contract:  (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method collections_create_collection" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `collections_create_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="str",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_delete_collection(self, collection_id, **kwargs):  # noqa: E501
        """Delete an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_delete_collection(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param bool force_delete:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_delete_collection_with_http_info(collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_delete_collection_with_http_info(collection_id, **kwargs)  # noqa: E501
            return data

    def collections_delete_collection_with_http_info(self, collection_id, **kwargs):  # noqa: E501
        """Delete an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_delete_collection_with_http_info(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param bool force_delete:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "force_delete"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method collections_delete_collection" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_delete_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []
        if "force_delete" in params:
            query_params.append(("forceDelete", params["force_delete"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_get_collection(self, collection_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_get_collection(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_get_collection_with_http_info(collection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_get_collection_with_http_info(collection_id, **kwargs)  # noqa: E501
            return data

    def collections_get_collection_with_http_info(self, collection_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_get_collection_with_http_info(collection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method collections_get_collection" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `collection_id` when calling `collections_get_collection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_get_collections(self, **kwargs):  # noqa: E501
        """Retrieve all accessible collection records.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_get_collections(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :return: list[ReducedCollectionView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_get_collections_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.collections_get_collections_with_http_info(**kwargs)  # noqa: E501
            return data

    def collections_get_collections_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible collection records.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_get_collections_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :return: list[ReducedCollectionView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["view"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method collections_get_collections" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "view" in params:
            query_params.append(("view", params["view"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ReducedCollectionView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_remove_schedule_from_collection(self, collection_id, schedule_id, **kwargs):  # noqa: E501
        """Remove a schedule from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_schedule_from_collection(collection_id, schedule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str schedule_id: Identifier for an existing schedule. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_remove_schedule_from_collection_with_http_info(collection_id, schedule_id, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_remove_schedule_from_collection_with_http_info(
                collection_id, schedule_id, **kwargs
            )  # noqa: E501
            return data

    def collections_remove_schedule_from_collection_with_http_info(self, collection_id, schedule_id, **kwargs):  # noqa: E501
        """Remove a schedule from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_schedule_from_collection_with_http_info(collection_id, schedule_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str schedule_id: Identifier for an existing schedule. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "schedule_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method collections_remove_schedule_from_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_remove_schedule_from_collection`"
            )  # noqa: E501
        # verify the required parameter 'schedule_id' is set
        if self.api_client.client_side_validation and ("schedule_id" not in params or params["schedule_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `schedule_id` when calling `collections_remove_schedule_from_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501
        if "schedule_id" in params:
            path_params["scheduleId"] = params["schedule_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/schedules/{scheduleId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_remove_user_from_collection(self, collection_id, user_id, **kwargs):  # noqa: E501
        """Remove a user from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_user_from_collection(collection_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_remove_user_from_collection_with_http_info(collection_id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_remove_user_from_collection_with_http_info(collection_id, user_id, **kwargs)  # noqa: E501
            return data

    def collections_remove_user_from_collection_with_http_info(self, collection_id, user_id, **kwargs):  # noqa: E501
        """Remove a user from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_user_from_collection_with_http_info(collection_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s' to method collections_remove_user_from_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_remove_user_from_collection`"
            )  # noqa: E501
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_id` when calling `collections_remove_user_from_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/users/{userId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_remove_user_group_from_collection(self, collection_id, user_group_id, **kwargs):  # noqa: E501
        """Remove a user group from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_user_group_from_collection(collection_id, user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_remove_user_group_from_collection_with_http_info(
                collection_id, user_group_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.collections_remove_user_group_from_collection_with_http_info(
                collection_id, user_group_id, **kwargs
            )  # noqa: E501
            return data

    def collections_remove_user_group_from_collection_with_http_info(self, collection_id, user_group_id, **kwargs):  # noqa: E501
        """Remove a user group from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_user_group_from_collection_with_http_info(collection_id, user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "user_group_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method collections_remove_user_group_from_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_remove_user_group_from_collection`"
            )  # noqa: E501
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `collections_remove_user_group_from_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/userGroups/{userGroupId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_remove_workflow_from_collection(self, collection_id, workflow_id, **kwargs):  # noqa: E501
        """Remove a workflow from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_workflow_from_collection(collection_id, workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str workflow_id: Identifier for an existing workflow or app. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_remove_workflow_from_collection_with_http_info(collection_id, workflow_id, **kwargs)  # noqa: E501
        else:
            (data) = self.collections_remove_workflow_from_collection_with_http_info(
                collection_id, workflow_id, **kwargs
            )  # noqa: E501
            return data

    def collections_remove_workflow_from_collection_with_http_info(self, collection_id, workflow_id, **kwargs):  # noqa: E501
        """Remove a workflow from an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_remove_workflow_from_collection_with_http_info(collection_id, workflow_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str workflow_id: Identifier for an existing workflow or app. (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "workflow_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method collections_remove_workflow_from_collection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_remove_workflow_from_collection`"
            )  # noqa: E501
        # verify the required parameter 'workflow_id' is set
        if self.api_client.client_side_validation and ("workflow_id" not in params or params["workflow_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `workflow_id` when calling `collections_remove_workflow_from_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501
        if "workflow_id" in params:
            path_params["workflowId"] = params["workflow_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/workflows/{workflowId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_update_collection(self, collection_id, update_collection_contract, **kwargs):  # noqa: E501
        """Update the name and/or owner of an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_update_collection(collection_id, update_collection_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param UpdateCollectionContract update_collection_contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_update_collection_with_http_info(
                collection_id, update_collection_contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.collections_update_collection_with_http_info(
                collection_id, update_collection_contract, **kwargs
            )  # noqa: E501
            return data

    def collections_update_collection_with_http_info(self, collection_id, update_collection_contract, **kwargs):  # noqa: E501
        """Update the name and/or owner of an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_update_collection_with_http_info(collection_id, update_collection_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param UpdateCollectionContract update_collection_contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "update_collection_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method collections_update_collection" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_update_collection`"
            )  # noqa: E501
        # verify the required parameter 'update_collection_contract' is set
        if self.api_client.client_side_validation and (
            "update_collection_contract" not in params or params["update_collection_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `update_collection_contract` when calling `collections_update_collection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_collection_contract" in params:
            body_params = params["update_collection_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_update_collection_user_group_permissions(
        self, collection_id, user_group_id, update_permissions_contract, **kwargs
    ):  # noqa: E501
        """Update a user group's permissions within an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_update_collection_user_group_permissions(collection_id, user_group_id, update_permissions_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :param UpdatePermissionsContract update_permissions_contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_update_collection_user_group_permissions_with_http_info(
                collection_id, user_group_id, update_permissions_contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.collections_update_collection_user_group_permissions_with_http_info(
                collection_id, user_group_id, update_permissions_contract, **kwargs
            )  # noqa: E501
            return data

    def collections_update_collection_user_group_permissions_with_http_info(
        self, collection_id, user_group_id, update_permissions_contract, **kwargs
    ):  # noqa: E501
        """Update a user group's permissions within an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_update_collection_user_group_permissions_with_http_info(collection_id, user_group_id, update_permissions_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :param UpdatePermissionsContract update_permissions_contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "user_group_id", "update_permissions_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method collections_update_collection_user_group_permissions" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_update_collection_user_group_permissions`"
            )  # noqa: E501
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `collections_update_collection_user_group_permissions`"
            )  # noqa: E501
        # verify the required parameter 'update_permissions_contract' is set
        if self.api_client.client_side_validation and (
            "update_permissions_contract" not in params or params["update_permissions_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `update_permissions_contract` when calling `collections_update_collection_user_group_permissions`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_permissions_contract" in params:
            body_params = params["update_permissions_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/userGroups/{userGroupId}/permissions",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def collections_update_collection_user_permissions(
        self, collection_id, user_id, update_permissions_contract, **kwargs
    ):  # noqa: E501
        """Update a user's permissions within an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  For Windows Authentication configured Server instances, provide the Active Directory Sid for the userId parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_update_collection_user_permissions(collection_id, user_id, update_permissions_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_id: Identifier for an existing user.  For Windows Authentication-configured Server instances, the Active Directory sid should be provided instead. (required)
        :param UpdatePermissionsContract update_permissions_contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.collections_update_collection_user_permissions_with_http_info(
                collection_id, user_id, update_permissions_contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.collections_update_collection_user_permissions_with_http_info(
                collection_id, user_id, update_permissions_contract, **kwargs
            )  # noqa: E501
            return data

    def collections_update_collection_user_permissions_with_http_info(
        self, collection_id, user_id, update_permissions_contract, **kwargs
    ):  # noqa: E501
        """Update a user's permissions within an existing collection.  # noqa: E501

        Only Curators can use this API endpoint.  For Windows Authentication configured Server instances, provide the Active Directory Sid for the userId parameter.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.collections_update_collection_user_permissions_with_http_info(collection_id, user_id, update_permissions_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str collection_id: Identifier for an existing collection. (required)
        :param str user_id: Identifier for an existing user.  For Windows Authentication-configured Server instances, the Active Directory sid should be provided instead. (required)
        :param UpdatePermissionsContract update_permissions_contract:  (required)
        :return: CollectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["collection_id", "user_id", "update_permissions_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method collections_update_collection_user_permissions" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'collection_id' is set
        if self.api_client.client_side_validation and (
            "collection_id" not in params or params["collection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `collection_id` when calling `collections_update_collection_user_permissions`"
            )  # noqa: E501
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_id` when calling `collections_update_collection_user_permissions`"
            )  # noqa: E501
        # verify the required parameter 'update_permissions_contract' is set
        if self.api_client.client_side_validation and (
            "update_permissions_contract" not in params or params["update_permissions_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `update_permissions_contract` when calling `collections_update_collection_user_permissions`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "collection_id" in params:
            path_params["collectionId"] = params["collection_id"]  # noqa: E501
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_permissions_contract" in params:
            body_params = params["update_permissions_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/collections/{collectionId}/users/{userId}/permissions",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CollectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMEGetConnectionView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "shared_by": "DCMEUserView",
        "shared_from_connection": "str",
        "connection_id": "str",
        "assigned_connection_ids": "list[str]",
        "created_on": "datetime",
        "last_changed_on": "datetime",
        "owner": "DCMEUserView",
        "sharing": "DCMESharingView",
        "id": "str",
        "name": "str",
        "schema_name": "str",
        "allow_in_sdks": "bool",
        "parameters": "dict(str, object)",
        "data_source": "DCMEDataSourceView",
        "credentials": "dict(str, DCMECredentialView)",
    }

    attribute_map = {
        "shared_by": "sharedBy",
        "shared_from_connection": "sharedFromConnection",
        "connection_id": "connectionId",
        "assigned_connection_ids": "assignedConnectionIds",
        "created_on": "createdOn",
        "last_changed_on": "lastChangedOn",
        "owner": "owner",
        "sharing": "sharing",
        "id": "id",
        "name": "name",
        "schema_name": "schemaName",
        "allow_in_sdks": "allowInSdks",
        "parameters": "parameters",
        "data_source": "dataSource",
        "credentials": "credentials",
    }

    def __init__(
        self,
        shared_by=None,
        shared_from_connection=None,
        connection_id=None,
        assigned_connection_ids=None,
        created_on=None,
        last_changed_on=None,
        owner=None,
        sharing=None,
        id=None,
        name=None,
        schema_name=None,
        allow_in_sdks=None,
        parameters=None,
        data_source=None,
        credentials=None,
        _configuration=None,
    ):  # noqa: E501
        """DCMEGetConnectionView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._shared_by = None
        self._shared_from_connection = None
        self._connection_id = None
        self._assigned_connection_ids = None
        self._created_on = None
        self._last_changed_on = None
        self._owner = None
        self._sharing = None
        self._id = None
        self._name = None
        self._schema_name = None
        self._allow_in_sdks = None
        self._parameters = None
        self._data_source = None
        self._credentials = None
        self.discriminator = None

        if shared_by is not None:
            self.shared_by = shared_by
        if shared_from_connection is not None:
            self.shared_from_connection = shared_from_connection
        if connection_id is not None:
            self.connection_id = connection_id
        self.assigned_connection_ids = assigned_connection_ids
        self.created_on = created_on
        self.last_changed_on = last_changed_on
        self.owner = owner
        if sharing is not None:
            self.sharing = sharing
        self.id = id
        self.name = name
        self.schema_name = schema_name
        self.allow_in_sdks = allow_in_sdks
        self.parameters = parameters
        self.data_source = data_source
        self.credentials = credentials

    @property
    def shared_by(self):
        """Gets the shared_by of this DCMEGetConnectionView.  # noqa: E501


        :return: The shared_by of this DCMEGetConnectionView.  # noqa: E501
        :rtype: DCMEUserView
        """
        return self._shared_by

    @shared_by.setter
    def shared_by(self, shared_by):
        """Sets the shared_by of this DCMEGetConnectionView.


        :param shared_by: The shared_by of this DCMEGetConnectionView.  # noqa: E501
        :type: DCMEUserView
        """

        self._shared_by = shared_by

    @property
    def shared_from_connection(self):
        """Gets the shared_from_connection of this DCMEGetConnectionView.  # noqa: E501


        :return: The shared_from_connection of this DCMEGetConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._shared_from_connection

    @shared_from_connection.setter
    def shared_from_connection(self, shared_from_connection):
        """Sets the shared_from_connection of this DCMEGetConnectionView.


        :param shared_from_connection: The shared_from_connection of this DCMEGetConnectionView.  # noqa: E501
        :type: str
        """

        self._shared_from_connection = shared_from_connection

    @property
    def connection_id(self):
        """Gets the connection_id of this DCMEGetConnectionView.  # noqa: E501

        Deprecated, will (probably) be removed in the future.  # noqa: E501

        :return: The connection_id of this DCMEGetConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this DCMEGetConnectionView.

        Deprecated, will (probably) be removed in the future.  # noqa: E501

        :param connection_id: The connection_id of this DCMEGetConnectionView.  # noqa: E501
        :type: str
        """

        self._connection_id = connection_id

    @property
    def assigned_connection_ids(self):
        """Gets the assigned_connection_ids of this DCMEGetConnectionView.  # noqa: E501


        :return: The assigned_connection_ids of this DCMEGetConnectionView.  # noqa: E501
        :rtype: list[str]
        """
        return self._assigned_connection_ids

    @assigned_connection_ids.setter
    def assigned_connection_ids(self, assigned_connection_ids):
        """Sets the assigned_connection_ids of this DCMEGetConnectionView.


        :param assigned_connection_ids: The assigned_connection_ids of this DCMEGetConnectionView.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and assigned_connection_ids is None:
            raise ValueError("Invalid value for `assigned_connection_ids`, must not be `None`")  # noqa: E501

        self._assigned_connection_ids = assigned_connection_ids

    @property
    def created_on(self):
        """Gets the created_on of this DCMEGetConnectionView.  # noqa: E501


        :return: The created_on of this DCMEGetConnectionView.  # noqa: E501
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DCMEGetConnectionView.


        :param created_on: The created_on of this DCMEGetConnectionView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and created_on is None:
            raise ValueError("Invalid value for `created_on`, must not be `None`")  # noqa: E501

        self._created_on = created_on

    @property
    def last_changed_on(self):
        """Gets the last_changed_on of this DCMEGetConnectionView.  # noqa: E501


        :return: The last_changed_on of this DCMEGetConnectionView.  # noqa: E501
        :rtype: datetime
        """
        return self._last_changed_on

    @last_changed_on.setter
    def last_changed_on(self, last_changed_on):
        """Sets the last_changed_on of this DCMEGetConnectionView.


        :param last_changed_on: The last_changed_on of this DCMEGetConnectionView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and last_changed_on is None:
            raise ValueError("Invalid value for `last_changed_on`, must not be `None`")  # noqa: E501

        self._last_changed_on = last_changed_on

    @property
    def owner(self):
        """Gets the owner of this DCMEGetConnectionView.  # noqa: E501


        :return: The owner of this DCMEGetConnectionView.  # noqa: E501
        :rtype: DCMEUserView
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this DCMEGetConnectionView.


        :param owner: The owner of this DCMEGetConnectionView.  # noqa: E501
        :type: DCMEUserView
        """
        if self._configuration.client_side_validation and owner is None:
            raise ValueError("Invalid value for `owner`, must not be `None`")  # noqa: E501

        self._owner = owner

    @property
    def sharing(self):
        """Gets the sharing of this DCMEGetConnectionView.  # noqa: E501


        :return: The sharing of this DCMEGetConnectionView.  # noqa: E501
        :rtype: DCMESharingView
        """
        return self._sharing

    @sharing.setter
    def sharing(self, sharing):
        """Sets the sharing of this DCMEGetConnectionView.


        :param sharing: The sharing of this DCMEGetConnectionView.  # noqa: E501
        :type: DCMESharingView
        """

        self._sharing = sharing

    @property
    def id(self):
        """Gets the id of this DCMEGetConnectionView.  # noqa: E501


        :return: The id of this DCMEGetConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DCMEGetConnectionView.


        :param id: The id of this DCMEGetConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this DCMEGetConnectionView.  # noqa: E501


        :return: The name of this DCMEGetConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DCMEGetConnectionView.


        :param name: The name of this DCMEGetConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def schema_name(self):
        """Gets the schema_name of this DCMEGetConnectionView.  # noqa: E501


        :return: The schema_name of this DCMEGetConnectionView.  # noqa: E501
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """Sets the schema_name of this DCMEGetConnectionView.


        :param schema_name: The schema_name of this DCMEGetConnectionView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and schema_name is None:
            raise ValueError("Invalid value for `schema_name`, must not be `None`")  # noqa: E501

        self._schema_name = schema_name

    @property
    def allow_in_sdks(self):
        """Gets the allow_in_sdks of this DCMEGetConnectionView.  # noqa: E501


        :return: The allow_in_sdks of this DCMEGetConnectionView.  # noqa: E501
        :rtype: bool
        """
        return self._allow_in_sdks

    @allow_in_sdks.setter
    def allow_in_sdks(self, allow_in_sdks):
        """Sets the allow_in_sdks of this DCMEGetConnectionView.


        :param allow_in_sdks: The allow_in_sdks of this DCMEGetConnectionView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and allow_in_sdks is None:
            raise ValueError("Invalid value for `allow_in_sdks`, must not be `None`")  # noqa: E501

        self._allow_in_sdks = allow_in_sdks

    @property
    def parameters(self):
        """Gets the parameters of this DCMEGetConnectionView.  # noqa: E501


        :return: The parameters of this DCMEGetConnectionView.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this DCMEGetConnectionView.


        :param parameters: The parameters of this DCMEGetConnectionView.  # noqa: E501
        :type: dict(str, object)
        """
        if self._configuration.client_side_validation and parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    @property
    def data_source(self):
        """Gets the data_source of this DCMEGetConnectionView.  # noqa: E501


        :return: The data_source of this DCMEGetConnectionView.  # noqa: E501
        :rtype: DCMEDataSourceView
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this DCMEGetConnectionView.


        :param data_source: The data_source of this DCMEGetConnectionView.  # noqa: E501
        :type: DCMEDataSourceView
        """
        if self._configuration.client_side_validation and data_source is None:
            raise ValueError("Invalid value for `data_source`, must not be `None`")  # noqa: E501

        self._data_source = data_source

    @property
    def credentials(self):
        """Gets the credentials of this DCMEGetConnectionView.  # noqa: E501


        :return: The credentials of this DCMEGetConnectionView.  # noqa: E501
        :rtype: dict(str, DCMECredentialView)
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this DCMEGetConnectionView.


        :param credentials: The credentials of this DCMEGetConnectionView.  # noqa: E501
        :type: dict(str, DCMECredentialView)
        """
        if self._configuration.client_side_validation and credentials is None:
            raise ValueError("Invalid value for `credentials`, must not be `None`")  # noqa: E501

        self._credentials = credentials

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMEGetConnectionView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMEGetConnectionView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMEGetConnectionView):
            return True

        return self.to_dict() != other.to_dict()



from mcp.server.fastmcp import FastMCP
from dotenv import load_dotenv
from src.tools import AYXMCPTools, InputData
from typing import List, Optional, Dict, Any


class MCPAlteryxServer:
    def __init__(self):
        """Initialize the MCP Alteryx Server"""
        self.tools = None
        self.app = None

    def initialize(self):
        """Initialize the server with tools and configuration"""
        # Load environment variables
        load_dotenv()

        # Initialize the AYXMCPTools instance
        self.tools = AYXMCPTools()

        # Initialize the setting for the FastMCP app
        # settings = {
        #     "debug": True,
        #     "log_level": "DEBUG",
        #     "host": "0.0.0.0",
        #     "port": 3001,
        # }
        # Initialize the FastMCP app
        self.app = FastMCP(
            name="mcp-alteryx-server",
            # settings=settings,
            prompt="""
# MCP Wrapper for Alteryx server

This MCP server provides tools for querying the remote Alteryx server using the Alteryx V3 API. It allows you to CRUD operations on Alteryx workflows, collections, users, jobs, connections and credendentials stored in the Alteryx server.

## Available Tools

### Collections
- get_all_collections: Get all collections
- get_collection_by_id: Get a specific collection
- create_collection: Create a new collection
- delete_collection: Delete a collection
- update_collection_name_or_owner: Update collection details
- add_workflow_to_collection: Add a workflow to a collection
- remove_workflow_from_collection: Remove a workflow from a collection
- add_schedule_to_collection: Add a schedule to a collection
- remove_schedule_from_collection: Remove a schedule from a collection

### Workflows
- get_all_workflows: Get all workflows
- get_workflow_by_id: Get a specific workflow
- update_workflow_name_or_comment: Update workflow details
- transfer_workflow: Transfer workflow ownership
- get_workflow_jobs: Get jobs for a workflow
- execute_workflow: Execute a workflow
- download_workflow_package_file: Download workflow package
- get_workflow_xml: Get workflow XML

### Users
- get_all_users: Get all users
- get_user_by_id: Get a specific user
- get_user_by_email: Get user by email
- get_user_by_name: Get user by name
- get_user_by_first_name: Get user by first name
- get_all_user_assets: Get all user assets
- get_user_assets_by_type: Get user assets by type
- update_user_details: Update user details
- transfer_all_assets: Transfer all user assets
- deactivate_user: Deactivate a user
- reset_user_password: Reset user password

### Jobs
- get_all_job_messages: Get all job messages
- get_job_by_id: Get a specific job

### Schedules
- get_all_schedules: Get all schedules
- get_schedule_by_id: Get a specific schedule
- deactivate_schedule: Deactivate a schedule
- activate_schedule: Activate a schedule
- update_schedule_name_or_comment: Update schedule details
- change_schedule_owner: Change schedule ownership

### Credentials and Connections
- get_all_credentials: Get all credentials
- get_credential_by_id: Get a specific credential
- lookup_connection: Lookup a connection
- get_connection_by_id: Get a specific connection

## Guidelines for Use

- Always check if a query would is about a workflow, a collection, a user, a job, a connection or a credential
- Keep queries concise and specific for best results
- Rate limits apply to all queries (typically 1 request/second)

## Output Format

All queries will be formatted as JSON for all results objects extracted from the Alteryx server.

- Workflow: Name, Description, and Created Date
- Collection: Name, Description, and Created Date
- User: Name, Email, and Created Date
- Job: Name, Description, and Created Date
- Connection: Name, Description, and Created Date
- Credential: Name, Description, and Created Date

If the API key is missing or invalid, appropriate error messages will be returned.
""",
        )
        return self

    def register_tools(self):
        """Register all tools with the MCP server"""
        if not self.app or not self.tools:
            raise RuntimeError("Server not initialized. Call initialize() first.")

        # Register Collections tools
        @self.app.tool()
        def get_all_collections():
            """Get the list of all collections of the Alteryx server"""
            return self.tools.get_all_collections()

        @self.app.tool()
        def get_collection_by_id(collection_id: str):
            """Get a collection by its ID"""
            return self.tools.get_collection_by_id(collection_id)

        @self.app.tool()
        def create_collection(name: str):
            """Create a new collection"""
            return self.tools.create_collection(name)

        @self.app.tool()
        def delete_collection(collection_id: str):
            """Delete a collection by its ID"""
            return self.tools.delete_collection(collection_id)

        @self.app.tool()
        def update_collection_name_or_owner(collection_id: str, name: str, owner_id: str):
            """Update a collection name or owner by its ID"""
            return self.tools.update_collection_name_or_owner(collection_id, name, owner_id)

        @self.app.tool()
        def add_workflow_to_collection(collection_id: str, workflow_id: str):
            """Add a workflow to a collection by its ID"""
            return self.tools.add_workflow_to_collection(collection_id, workflow_id)

        @self.app.tool()
        def remove_workflow_from_collection(collection_id: str, workflow_id: str):
            """Remove a workflow from a collection by its ID"""
            return self.tools.remove_workflow_from_collection(collection_id, workflow_id)

        @self.app.tool()
        def add_schedule_to_collection(collection_id: str, schedule_id: str):
            """Add a schedule to a collection by its ID"""
            return self.tools.add_schedule_to_collection(collection_id, schedule_id)

        @self.app.tool()
        def remove_schedule_from_collection(collection_id: str, schedule_id: str):
            """Remove a schedule from a collection by its ID"""
            return self.tools.remove_schedule_from_collection(collection_id, schedule_id)

        # Register Workflows tools
        @self.app.tool()
        def get_all_workflows():
            """Get the list of all workflows of the Alteryx server"""
            return self.tools.get_all_workflows()

        @self.app.tool()
        def get_workflow_by_id(workflow_id: str):
            """Get a workflow by its ID"""
            return self.tools.get_workflow_by_id(workflow_id)

        @self.app.tool()
        def update_workflow_name_or_comment(workflow_id: str, name: str, comment: str):
            """Update a workflow name or comment by its ID"""
            return self.tools.update_workflow_name_or_comment(workflow_id, name, comment)

        @self.app.tool()
        def download_workflow_package_file(workflow_id: str, output_directory: str):
            """Download a workflow package file by its ID and save it to the local directory"""
            return self.tools.download_workflow_package_file(workflow_id, output_directory)

        @self.app.tool()
        def get_workflow_xml(workflow_id: str):
            """Get the XML representation of a workflow file by its ID"""
            return self.tools.get_workflow_xml(workflow_id)

        @self.app.tool()
        def transfer_workflow(workflow_id: str, new_owner_id: str):
            """Transfer workflow ownership to a new user"""
            return self.tools.transfer_workflow(workflow_id, new_owner_id)

        @self.app.tool()
        def get_workflow_jobs(workflow_id: str):
            """Get all jobs associated with a workflow"""
            return self.tools.get_workflow_jobs(workflow_id)

        @self.app.tool()
        def start_workflow_execution(workflow_id: str, input_data: list[InputData] = None):
            """Start a workflow execution by its ID and return the job ID. 
            This will create a new job and add it to the execution queue.
            This call will return a job ID that can be used to get the job details later. 
            The input data is a list of name-value pairs, each containing a name and value."""
            return self.tools.start_workflow_execution(workflow_id, input_data)
        
        @self.app.tool()
        def execute_workflow_with_monitoring(
                workflow_id: str, 
                input_data: list[InputData] = None
        ):
            """Execute a workflow by its ID and monitor its execution status. This call will return a jobID, he Job status and the job details once the execution is completed or failed.
            The input data parameter is a list of name-value pairs, each containing a name and value. """
            return self.tools.execute_workflow_with_monitoring(
                workflow_id, 
                input_data, 
                wait_for_completion=True,
                timeout_seconds=300,  # 5 minutes timeout
                poll_interval_seconds=10
            )

        # Register Users tools
        @self.app.tool()
        def get_all_users():
            """Get the list of all users of the Alteryx server"""
            return self.tools.get_all_users()

        @self.app.tool()
        def get_user_by_id(user_id: str):
            """Get a user by their ID"""
            return self.tools.get_user_by_id(user_id)

        @self.app.tool()
        def get_user_by_email(email: str):
            """Get a user by their email"""
            return self.tools.get_user_by_email(email)

        @self.app.tool()
        def get_user_by_name(name: str):
            """Get a user by their last name"""
            return self.tools.get_user_by_name(name)

        @self.app.tool()
        def get_user_by_first_name(first_name: str):
            """Get a user by their first name"""
            return self.tools.get_user_by_first_name(first_name)

        @self.app.tool()
        def get_all_user_assets(user_id: str):
            """Get all the assets for a user"""
            return self.tools.get_all_user_assets(user_id)

        @self.app.tool()
        def get_user_assets_by_type(user_id: str, asset_type: str):
            """Get user assets by type"""
            return self.tools.get_user_assets_by_type(user_id, asset_type)

        @self.app.tool()
        def update_user_details(user_id: str, first_name: str, last_name: str, email: str):
            """Update details of an existing user by their ID"""
            return self.tools.update_user_details(user_id, first_name, last_name, email)

        @self.app.tool()
        def transfer_all_assets(user_id: str, new_owner_id: str):
            """Transfer all assets from one user to another"""
            return self.tools.transfer_all_assets(user_id, new_owner_id)

        @self.app.tool()
        def deactivate_user(user_id: str):
            """Deactivate a user account"""
            return self.tools.deactivate_user(user_id)

        @self.app.tool()
        def reset_user_password(user_id: str):
            """Reset a user's password by their ID"""
            return self.tools.reset_user_password(user_id)

        # Register Jobs tools
        @self.app.tool()
        def get_all_job_messages(job_id: str):
            """Get all the messages for a job"""
            return self.tools.get_all_job_messages(job_id)

        @self.app.tool()
        def get_job_by_id(job_id: str):
            """Retrieve details about an existing job and its current state"""
            return self.tools.get_job_by_id(job_id)

        # Register Schedules tools
        @self.app.tool()
        def get_all_schedules():
            """Get the list of all schedules of the Alteryx server"""
            return self.tools.get_all_schedules()

        @self.app.tool()
        def get_schedule_by_id(schedule_id: str):
            """Get a schedule by its ID"""
            return self.tools.get_schedule_by_id(schedule_id)

        @self.app.tool()
        def deactivate_schedule(schedule_id: str):
            """Deactivate a schedule by its ID"""
            return self.tools.deactivate_schedule(schedule_id)

        @self.app.tool()
        def activate_schedule(schedule_id: str):
            """Activate a schedule by its ID"""
            return self.tools.activate_schedule(schedule_id)

        @self.app.tool()
        def update_schedule_name_or_comment(schedule_id: str, name: str, comment: str):
            """Update a schedule name or comment by its ID"""
            return self.tools.update_schedule_name_or_comment(schedule_id, name, comment)

        @self.app.tool()
        def change_schedule_owner(schedule_id: str, new_owner_id: str):
            """Change the owner of a schedule by its ID"""
            return self.tools.change_schedule_owner(schedule_id, new_owner_id)

        # Register Credentials tools
        @self.app.tool()
        def get_all_credentials():
            """Get the list of all accessible credentials of the Alteryx server"""
            return self.tools.get_all_credentials()

        @self.app.tool()
        def get_credential_by_id(credential_id: str):
            """Get the details of an existing credential"""
            return self.tools.get_credential_by_id(credential_id)

        # Register Connections tools
        @self.app.tool()
        def lookup_connection(connection_id: str):
            """Lookup a DCM Connection as referenced in workflows"""
            return self.tools.lookup_connection(connection_id)

        @self.app.tool()
        def get_connection_by_id(connection_id: str):
            """Get a connection by its ID"""
            return self.tools.get_connection_by_id(connection_id)

        return self



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class ReducedWorkflowView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "source_app_id": "str",
        "name": "str",
        "owner_id": "str",
        "date_created": "datetime",
        "published_version_number": "int",
        "is_amp": "bool",
        "execution_mode": "str",
    }

    attribute_map = {
        "id": "id",
        "source_app_id": "sourceAppId",
        "name": "name",
        "owner_id": "ownerId",
        "date_created": "dateCreated",
        "published_version_number": "publishedVersionNumber",
        "is_amp": "isAmp",
        "execution_mode": "executionMode",
    }

    def __init__(
        self,
        id=None,
        source_app_id=None,
        name=None,
        owner_id=None,
        date_created=None,
        published_version_number=None,
        is_amp=None,
        execution_mode=None,
        _configuration=None,
    ):  # noqa: E501
        """ReducedWorkflowView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._source_app_id = None
        self._name = None
        self._owner_id = None
        self._date_created = None
        self._published_version_number = None
        self._is_amp = None
        self._execution_mode = None
        self.discriminator = None

        self.id = id
        self.source_app_id = source_app_id
        self.name = name
        self.owner_id = owner_id
        self.date_created = date_created
        self.published_version_number = published_version_number
        self.is_amp = is_amp
        self.execution_mode = execution_mode

    @property
    def id(self):
        """Gets the id of this ReducedWorkflowView.  # noqa: E501


        :return: The id of this ReducedWorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReducedWorkflowView.


        :param id: The id of this ReducedWorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def source_app_id(self):
        """Gets the source_app_id of this ReducedWorkflowView.  # noqa: E501


        :return: The source_app_id of this ReducedWorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._source_app_id

    @source_app_id.setter
    def source_app_id(self, source_app_id):
        """Sets the source_app_id of this ReducedWorkflowView.


        :param source_app_id: The source_app_id of this ReducedWorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and source_app_id is None:
            raise ValueError("Invalid value for `source_app_id`, must not be `None`")  # noqa: E501

        self._source_app_id = source_app_id

    @property
    def name(self):
        """Gets the name of this ReducedWorkflowView.  # noqa: E501


        :return: The name of this ReducedWorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReducedWorkflowView.


        :param name: The name of this ReducedWorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def owner_id(self):
        """Gets the owner_id of this ReducedWorkflowView.  # noqa: E501


        :return: The owner_id of this ReducedWorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this ReducedWorkflowView.


        :param owner_id: The owner_id of this ReducedWorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and owner_id is None:
            raise ValueError("Invalid value for `owner_id`, must not be `None`")  # noqa: E501

        self._owner_id = owner_id

    @property
    def date_created(self):
        """Gets the date_created of this ReducedWorkflowView.  # noqa: E501


        :return: The date_created of this ReducedWorkflowView.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this ReducedWorkflowView.


        :param date_created: The date_created of this ReducedWorkflowView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def published_version_number(self):
        """Gets the published_version_number of this ReducedWorkflowView.  # noqa: E501


        :return: The published_version_number of this ReducedWorkflowView.  # noqa: E501
        :rtype: int
        """
        return self._published_version_number

    @published_version_number.setter
    def published_version_number(self, published_version_number):
        """Sets the published_version_number of this ReducedWorkflowView.


        :param published_version_number: The published_version_number of this ReducedWorkflowView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and published_version_number is None:
            raise ValueError("Invalid value for `published_version_number`, must not be `None`")  # noqa: E501

        self._published_version_number = published_version_number

    @property
    def is_amp(self):
        """Gets the is_amp of this ReducedWorkflowView.  # noqa: E501


        :return: The is_amp of this ReducedWorkflowView.  # noqa: E501
        :rtype: bool
        """
        return self._is_amp

    @is_amp.setter
    def is_amp(self, is_amp):
        """Sets the is_amp of this ReducedWorkflowView.


        :param is_amp: The is_amp of this ReducedWorkflowView.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_amp is None:
            raise ValueError("Invalid value for `is_amp`, must not be `None`")  # noqa: E501

        self._is_amp = is_amp

    @property
    def execution_mode(self):
        """Gets the execution_mode of this ReducedWorkflowView.  # noqa: E501


        :return: The execution_mode of this ReducedWorkflowView.  # noqa: E501
        :rtype: str
        """
        return self._execution_mode

    @execution_mode.setter
    def execution_mode(self, execution_mode):
        """Sets the execution_mode of this ReducedWorkflowView.


        :param execution_mode: The execution_mode of this ReducedWorkflowView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and execution_mode is None:
            raise ValueError("Invalid value for `execution_mode`, must not be `None`")  # noqa: E501
        allowed_values = ["Safe", "SemiSafe", "Standard"]  # noqa: E501
        if self._configuration.client_side_validation and execution_mode not in allowed_values:
            raise ValueError(
                "Invalid value for `execution_mode` ({0}), must be one of {1}".format(execution_mode, allowed_values)  # noqa: E501
            )

        self._execution_mode = execution_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ReducedWorkflowView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReducedWorkflowView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReducedWorkflowView):
            return True

        return self.to_dict() != other.to_dict()
